@@ -44,8 +44,8 @@ static void on_remove_file_clicked(GtkButton *button, gpointer user_data);
 static void on_save_file_clicked(GtkButton *button, gpointer user_data);
 static void on_close_clicked (GtkButton *button, gpointer user_data);
 static gboolean att_list_on_drop(GtkWidget *widget, GdkDragContext *drag_context, gint x, gint y, guint time, gpointer user_data);
-static void att_list_drag_data_received(GtkWidget *widget, GdkDragContext *context, gint x, gint y, 
-        GtkSelectionData *selection_data, guint target_type, guint time, 
+static void att_list_drag_data_received(GtkWidget *widget, GdkDragContext *context, gint x, gint y,
+        GtkSelectionData *selection_data, guint target_type, guint time,
         gpointer data);
 gboolean is_format_provided(GdkDragContext *context, GdkAtom target);
 void on_item_executed (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *col, gpointer  userdata);
@@ -123,7 +123,8 @@ GtkWidget* FileAttachmentDlg::create_dialog (GtkWidget* parent)
 	GtkWidget *remove_btn;
 	GtkWidget *save_btn;
 	GtkWidget *close_btn;
-	
+	GtkWidget *scrolledwindow1;
+
 	attachments_dialog = gtk_dialog_new ();
 	gtk_window_set_title (GTK_WINDOW (attachments_dialog), _("Node attachments"));
 	gtk_window_set_modal (GTK_WINDOW (attachments_dialog), TRUE);
@@ -141,11 +142,15 @@ GtkWidget* FileAttachmentDlg::create_dialog (GtkWidget* parent)
 	#endif
 #endif
 	gtk_widget_realize(attachments_dialog);
-	gdk_window_set_decorations(attachments_dialog->window, (GdkWMDecoration)(GDK_DECOR_BORDER|GDK_DECOR_TITLE));
-	
+
 	dialog_vbox6 = GTK_DIALOG (attachments_dialog)->vbox;
 	gtk_widget_show (dialog_vbox6);
-	
+
+	scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
+	gtk_widget_show (scrolledwindow1);
+	gtk_box_pack_start (GTK_BOX (dialog_vbox6), scrolledwindow1, TRUE, TRUE, 0);
+
 	// create file list
 	GtkListStore *store = gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_INT, G_TYPE_STRING);
   	GtkWidget *treeview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
@@ -159,12 +164,13 @@ GtkWidget* FileAttachmentDlg::create_dialog (GtkWidget* parent)
 	};
 	gtk_drag_dest_set(GTK_WIDGET(treeview), GTK_DEST_DEFAULT_ALL, targets, G_N_ELEMENTS (targets), GdkDragAction(GDK_ACTION_COPY));
 
-	gtk_box_pack_start (GTK_BOX (dialog_vbox6), treeview, FALSE, FALSE, 0);
-	gtk_widget_show (treeview);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(treeview), TRUE);
 	gtk_tree_view_set_headers_clickable (GTK_TREE_VIEW(treeview), TRUE);
 	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(treeview),FALSE);
-	
+
+	gtk_widget_show (treeview);
+	gtk_container_add( GTK_CONTAINER(scrolledwindow1), treeview );
+
 	GtkTreeViewColumn *col = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(col, _("Name"));
 	gtk_tree_view_column_set_clickable(col, TRUE);	//allow column header clicks
@@ -176,7 +182,7 @@ GtkWidget* FileAttachmentDlg::create_dialog (GtkWidget* parent)
 	GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
 
 	gtk_tree_view_column_pack_start(col, renderer, TRUE);
-	gtk_tree_view_column_add_attribute(col, renderer, "text", 0); 
+	gtk_tree_view_column_add_attribute(col, renderer, "text", 0);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), col);
 
 	col = gtk_tree_view_column_new();
@@ -189,7 +195,7 @@ GtkWidget* FileAttachmentDlg::create_dialog (GtkWidget* parent)
 //	g_signal_connect (col, "clicked", G_CALLBACK (on_header_clicked), this);
 
 	gtk_tree_view_column_pack_start(col, renderer, TRUE);
-	gtk_tree_view_column_add_attribute(col, renderer, "text", 1); 
+	gtk_tree_view_column_add_attribute(col, renderer, "text", 1);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), col);
 
 
@@ -211,7 +217,7 @@ GtkWidget* FileAttachmentDlg::create_dialog (GtkWidget* parent)
 	gtk_widget_show (save_btn);
 	gtk_container_add (GTK_CONTAINER(dialog_action_area6), save_btn);
 	GTK_WIDGET_SET_FLAGS (save_btn, GTK_CAN_DEFAULT);
-		
+
 	close_btn = gtk_button_new_with_mnemonic (_("Close"));
 	gtk_widget_show (close_btn);
 	gtk_container_add (GTK_CONTAINER(dialog_action_area6), close_btn);
@@ -235,7 +241,7 @@ GtkWidget* FileAttachmentDlg::create_dialog (GtkWidget* parent)
 	GLADE_HOOKUP_OBJECT (attachments_dialog, remove_btn, "remove_btn");
 	GLADE_HOOKUP_OBJECT (attachments_dialog, save_btn, "save_btn");
 	GLADE_HOOKUP_OBJECT (attachments_dialog, close_btn, "close_btn");
-	
+
 	gtk_widget_grab_default (close_btn);
 
 	return attachments_dialog;
@@ -340,7 +346,7 @@ void on_add_file_clicked (GtkButton *button, gpointer user_data)
 		pAction->m_info = info;
 		pAction->m_nNodeIdx = pDlg->m_nNodeIdx;
 		pAction->m_nAttIdx    = g_doc.GetNodeByIdx(pDlg->m_nNodeIdx).m_lstAttachments.size()-1;
-		
+
 		g_undoManager.AddAction(pAction);
 		UpdateUndoRedoMenus();
 	}
@@ -366,7 +372,7 @@ void on_remove_file_clicked(GtkButton *button, gpointer user_data)
 		pAction->m_info		= g_doc.GetNodeByIdx(pDlg->m_nNodeIdx).m_lstAttachments[nSelIdx];
 		pAction->m_nNodeIdx = pDlg->m_nNodeIdx;
 		pAction->m_nAttIdx  = nSelIdx;
-		
+
 		g_undoManager.AddAction(pAction);
 		UpdateUndoRedoMenus();
 
@@ -384,7 +390,7 @@ void on_remove_file_clicked(GtkButton *button, gpointer user_data)
 		GtkTreeIter iter;
 		gint bResult = gtk_tree_model_get_iter(store, &iter, path1);
 		gtk_tree_path_free(path1);
-		
+
 		if(bResult)
 			gtk_list_store_remove((GtkListStore *)store, &iter);
 
@@ -448,7 +454,7 @@ void on_save_file_clicked (GtkButton *button, gpointer user_data)
 
 		//show wait dialog (only if not from cmd line)
 		ProgressDlg dlg(200, _("Saving file. Please wait..."), window1);
-	
+
 		int nSize = g_doc.GetNodeByIdx(pDlg->m_nNodeIdx).m_lstAttachments[nSelRow].nDataSize;
 		const char *szData = g_doc.GetNodeByIdx(pDlg->m_nNodeIdx).m_lstAttachments[nSelRow].m_strData.c_str();
 
@@ -460,7 +466,7 @@ void on_save_file_clicked (GtkButton *button, gpointer user_data)
 
 		while(nPos < nSize-1)
 		{
-			nSaveStep = min(nChunkSize, nSize-nPos);			
+			nSaveStep = min(nChunkSize, nSize-nPos);
 			nWritten = file.Write(szData+nPos, nSaveStep);
 			nPos += nSaveStep;
 
@@ -487,7 +493,7 @@ gboolean att_list_on_drop(GtkWidget *widget, GdkDragContext *context, gint x, gi
 		gtkMessageBox(_("Can not change read-only document!"));
 		return FALSE;
 	}
-    
+
 	TRACE("DnD: att_list_on_drop\n");
 
 	gboolean  is_valid_drop_site = TRUE;
@@ -500,7 +506,7 @@ gboolean att_list_on_drop(GtkWidget *widget, GdkDragContext *context, gint x, gi
 			target_type = atomTextUriList;
 		else
 			return FALSE;
-        
+
         // Request the data from the source, actual data will be received by 'drag-data-received' signal
         gtk_drag_get_data( widget, context, target_type, time);
     }
@@ -508,12 +514,12 @@ gboolean att_list_on_drop(GtkWidget *widget, GdkDragContext *context, gint x, gi
 	{
 		is_valid_drop_site = FALSE;	// No target offered by source => error
 	}
-        
+
 	return  is_valid_drop_site;
 }
 
 void att_list_drag_data_received(GtkWidget *widget, GdkDragContext *context, gint x, gint y, GtkSelectionData *selection_data, guint target_type, guint time, gpointer data)
-{       
+{
 	TRACE("DnD: att_list_drag_data_received\n");
 
 	FileAttachmentDlg *pDlg = (FileAttachmentDlg *)data;
@@ -529,7 +535,7 @@ void att_list_drag_data_received(GtkWidget *widget, GdkDragContext *context, gin
 	TRACE("%s: att_list_drag_data_received\n", name);
 
 	// Deal with what we are given from source
-	if( (selection_data != NULL) && 
+	if( (selection_data != NULL) &&
 		(selection_data->length >= 0))
 	{
 		if (context->action == GDK_ACTION_ASK)
@@ -656,6 +662,14 @@ void att_list_drag_data_received(GtkWidget *widget, GdkDragContext *context, gin
 					g_undoManager.AddAction(pAction);
 					UpdateUndoRedoMenus();
 				}
+
+				//force redraw to refresh scroll bar
+				gdk_window_clear_area (treeview->window,
+                        treeview->allocation.x,
+                        treeview->allocation.y,
+                        treeview->allocation.width,
+                        treeview->allocation.height);
+				gtk_widget_queue_draw (treeview);
 			}
 		}
 	}
