@@ -13,6 +13,7 @@
 #pragma once
 #endif // _MSC_VER > 1000
 
+#include "config.h"
 #include "gui/Dialog.h"
 #include <string>
 
@@ -22,7 +23,7 @@
 #define ICON_INTERNAL_FIRST 0
 #define ICON_INTERNAL_LAST	5
 
-class NodePropertiesDlg : public Dialog  
+class NodePropertiesDlg : public Dialog
 {
 public:
 	NodePropertiesDlg();
@@ -31,6 +32,10 @@ public:
 
 	std::string GetNodeTitle();
 
+	#ifdef HAVE_GTKSOURCEVIEW
+		std::string GetSourceLanguage();
+	#endif
+
 	int GetIconType();
 	void SetIconType(int nType);
 
@@ -44,6 +49,9 @@ public:
 	void RefreshKeywords();
 
 public:
+	#ifdef HAVE_GTKSOURCEVIEW
+	std::string m_strSourceLanguage;
+	#endif	
 	std::string m_strTitle;
 	std::string m_strKeywords;
 	time_t	m_nCreated;
