@@ -9,6 +9,12 @@
 #include "TextView.h"
 #include "config.h"
 
+#ifdef HAVE_GTKSOURCEVIEW
+	#include <gtksourceview/gtksourceview.h>
+	#include <gtksourceview/gtksourcelanguage.h>
+	#include <gtksourceview/gtksourcelanguagemanager.h>
+#endif
+
 //declare signal handlers
 void on_textview_edited (GtkTextBuffer *, gpointer data);
 void on_delete_text (GtkTextBuffer *textbuffer, GtkTextIter *arg1, GtkTextIter *arg2, gpointer user_data);
@@ -26,6 +32,13 @@ extern GdkColor g_linkColor;
 GdkAtom atomTextUriList;
 GdkAtom atomString;
 
+#ifdef HAVE_GTKSOURCEVIEW
+GtkSourceBuffer *gtk_source_view_get_buffer(GtkSourceView *view)
+{
+	return GTK_SOURCE_BUFFER(GTK_TEXT_VIEW(view)->buffer);
+}
+#endif
+
 TextView::TextView()
 {
 	m_pWidget = NULL;
@@ -39,8 +52,8 @@ void TextView::Create()
 {
 	GtkWidget *textview1;
 
-	GtkTextBuffer *buffer = gtk_text_buffer_new (NULL);
-	textview1 = gtk_text_view_new_with_buffer (buffer);
+	GTK_TEXTBUFFER_CLASS *buffer = GTK_TEXTBUFFER_CLASS_NEW (NULL);
+	textview1 = GTK_TEXTVIEW_CLASS_NEW (buffer);
 	gtk_widget_show (textview1);
 
 	g_signal_connect (G_OBJECT (textview1), "key_press_event", G_CALLBACK (textview_keyboard_handler), NULL);
@@ -60,7 +73,7 @@ void TextView::Create()
 	gtk_widget_tap_and_hold_setup(GTK_WIDGET(textview1), NULL, NULL, (GtkWidgetTapAndHoldFlags)(GTK_TAP_AND_HOLD_PASS_PRESS /*GTK_TAP_AND_HOLD_NONE | GTK_TAP_AND_HOLD_NO_INTERNALS*/));
 	//g_signal_connect(treeview1, "tap-and-hold", G_CALLBACK(on_popup_menu), NULL);
 #endif
- 
+
 	g_signal_connect(buffer, "changed", G_CALLBACK(on_textview_edited),  NULL); //track buffer changes
 
 	//events to handle undo in textview
@@ -83,7 +96,7 @@ void TextView::Clear()
 	gtk_text_buffer_get_iter_at_offset(buffer1, &itStart, 0);
 	gtk_text_buffer_get_iter_at_offset(buffer1, &itEnd, gtk_text_buffer_get_char_count(buffer1));
 
-	gtk_text_buffer_remove_all_tags(buffer1, &itStart, &itEnd); 
+	gtk_text_buffer_remove_all_tags(buffer1, &itStart, &itEnd);
 
 	g_signal_handlers_block_by_func(buffer1, (void *)on_delete_text, 0);
 	g_signal_handlers_block_by_func(buffer1, (void *)on_textview_edited, 0);
@@ -119,7 +132,7 @@ void TextView::SetText(const gchar *szText)
 
 	gtk_text_buffer_insert_at_cursor(buffer1, szText, -1);
 	gtk_text_view_place_cursor_onscreen(GTK_TEXT_VIEW(textview));
-	
+
 	g_signal_handlers_unblock_by_func(buffer1, (void *)on_textview_edited, 0);
 	g_signal_handlers_unblock_by_func(buffer1, (void *)on_insert_text, 0);
 }
@@ -146,7 +159,7 @@ void TextView::DeleteText(int nOffset, int nLength)
 {
 	GtkTextView *textview =  (GtkTextView *)m_pWidget;
 	GtkTextBuffer* buffer1 = gtk_text_view_get_buffer(textview);
-	
+
 	GtkTextIter itStart, itEnd;
 	gtk_text_buffer_get_iter_at_offset(buffer1, &itStart, nOffset);
 	gtk_text_buffer_get_iter_at_offset(buffer1, &itEnd, nOffset+nLength);
@@ -230,7 +243,7 @@ void TextView::SelectRange(int nStart, int nEnd)
 	gtk_text_buffer_get_iter_at_offset(buffer1, &iterEnd, nEnd);
 #if GTK_CHECK_VERSION(2,4,0) //define minimal version for this api
 	gtk_text_buffer_select_range(buffer1, &iterStart, &iterEnd);
-#endif	
+#endif
 }
 
 void TextView::EnsureVisible(int nOffset)
@@ -276,7 +289,7 @@ void TextView::SetFocus()
  	//view cursor in a TextView
  	gtk_text_view_scroll_mark_onscreen (
  		GTK_TEXT_VIEW(m_pWidget),
-		gtk_text_buffer_get_insert( gtk_text_view_get_buffer( GTK_TEXT_VIEW(m_pWidget) ) ) 
+		gtk_text_buffer_get_insert( gtk_text_view_get_buffer( GTK_TEXT_VIEW(m_pWidget) ) )
 	);
 }
 
@@ -289,7 +302,7 @@ void TextView::GetSelectionBounds(int& cursor, int& selection)
 	GtkTextView *textview =  (GtkTextView *)m_pWidget;
 	GtkTextBuffer* buffer1 = gtk_text_view_get_buffer(textview);
 	GtkTextIter iter;
-	
+
 	gtk_text_buffer_get_iter_at_mark (buffer1, &iter, gtk_text_buffer_get_insert (buffer1) );
 	cursor = gtk_text_iter_get_offset(&iter);
 
@@ -305,7 +318,7 @@ void TextView::RestoreSelectionBounds(unsigned int cursor, unsigned int selectio
 
 	gtk_text_buffer_get_iter_at_offset( buffer1, &cursIter, gint(cursor) );
 	gtk_text_buffer_get_iter_at_offset( buffer1, &boundIter, gint(selection) );
-	
+
 	gtk_text_buffer_select_range ( buffer1, &cursIter, &boundIter );
 }
 
@@ -354,7 +367,7 @@ std::string TextView::GetSelectedText()
 	GtkTextView *textview =  (GtkTextView *)m_pWidget;
 	GtkTextBuffer* buffer1 = gtk_text_view_get_buffer(textview);
 	GtkTextIter iterStart, iterEnd;
-	
+
 	gtk_text_buffer_get_iter_at_mark (buffer1, &iterStart, gtk_text_buffer_get_insert (buffer1) );
 	gtk_text_buffer_get_iter_at_mark (buffer1, &iterEnd, gtk_text_buffer_get_selection_bound (buffer1) );
 
@@ -398,7 +411,7 @@ void TextView::SetTextUnderlined(int nStart, int nEnd)
 	GtkTextTag *tag = gtk_text_buffer_create_tag (buffer1, NULL,
 			"foreground", szColor,
 			"underline", PANGO_UNDERLINE_SINGLE,
-			"underline-set", TRUE, 
+			"underline-set", TRUE,
 			NULL);
 	gtk_text_buffer_apply_tag(buffer1, tag, &cursIter, &boundIter);
 }
@@ -448,3 +461,16 @@ int TextView::CalcTabWidthInPixels(int nNumChars)
 	return tab_width;
 }
 
+#ifdef HAVE_GTKSOURCEVIEW
+void TextView::SetSourceLanguage(const gchar *szSourceLanguage)
+{
+    if(szSourceLanguage)
+    {
+        GtkSourceLanguageManager *manager = gtk_source_language_manager_get_default();
+        GtkSourceLanguage *language = gtk_source_language_manager_get_language (manager, szSourceLanguage);
+				GtkSourceView *textview =  (GtkSourceView *)m_pWidget;
+				GtkSourceBuffer* buffer1 = gtk_source_view_get_buffer(textview);
+        gtk_source_buffer_set_language(buffer1, language);
+    }
+}
+#endif
