@@ -13,7 +13,7 @@
 #include "lib/LinkInfo.h"
 #include "lib/NoteDocument.h"
 
-void edit_node_title();
+void edit_node_title(int nSelFrom = -1, int nSelLen = -1, const char *szTitle = NULL);
 void UpdateTextFromScreen();
 void UpdateUndoRedoMenus();
 void ExecuteLink(LinkInfo &link);
@@ -22,7 +22,7 @@ int GetSelectedNodeIdx();
 extern NoteDocument g_doc;
 
 //declare signal handlers
-gboolean treeview1_popup_menu_event_handler (GtkWidget *widget, GdkEventButton *event, gpointer user_data);	
+gboolean treeview1_popup_menu_event_handler (GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 void cell_edited_callback(GtkCellRendererText *cell, gchar *path_string, gchar *new_text, gpointer user_data);
 void cell_edited_start_callback (GtkCellRenderer *renderer, GtkCellEditable *editable, gchar *path, gpointer user_data);
 void cell_edited_cancel_callback (GtkCellRenderer *renderer, gpointer user_data);
@@ -63,14 +63,14 @@ void TreeView::Create()
 	//
 	// tree initialization
 	//
-	
+
 	// data store: title, icon, strikethrough, underline, node color
 	store = gtk_tree_store_new(5, G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_BOOLEAN, G_TYPE_UINT, GDK_TYPE_COLOR);
 	treeview1 = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
 	g_object_unref (G_OBJECT (store));  //tree now holds reference
 
 	gtk_tree_view_set_headers_visible((GtkTreeView *)treeview1, FALSE);
-	gtk_tree_view_set_enable_search((GtkTreeView *)treeview1, FALSE); 
+	gtk_tree_view_set_enable_search((GtkTreeView *)treeview1, FALSE);
 	//g_object_set (treeview1, "level_indentation", 10, (char *)NULL);
 	gtk_widget_show (treeview1);
 
@@ -100,9 +100,9 @@ void TreeView::Create()
 	g_object_set(renderer, "foreground-set", TRUE, (char *)NULL);
 
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes(column, renderer, 
-			"text",           STORE_IDX_TEXT, 
-			"strikethrough",  STORE_IDX_STRIKE, 
+	gtk_tree_view_column_set_attributes(column, renderer,
+			"text",           STORE_IDX_TEXT,
+			"strikethrough",  STORE_IDX_STRIKE,
 			"underline",      STORE_IDX_UNDERLINE,
 			"foreground-gdk", STORE_IDX_COLOR,
 			(char *)NULL);
@@ -149,7 +149,7 @@ void TreeView::EditLabel()
 		GtkCellRendererText *renderer = (GtkCellRendererText *)g_list_nth_data(list1, SCREEN_IDX_TEXT);
 		GtkTreePath* path1 = gtk_tree_model_get_path(model, &iter);
 		g_object_set(renderer, "editable", TRUE, (char *)NULL);	//makes tree cells editable
-		gtk_tree_view_set_cursor(treeview, path1, column1, TRUE);	//trigger 
+		gtk_tree_view_set_cursor(treeview, path1, column1, TRUE);	//trigger
 		g_object_set(renderer, "editable", FALSE, (char *)NULL);//makes tree cells non-editable
 		g_list_free(list1);
 		gtk_tree_path_free(path1);
@@ -186,7 +186,7 @@ bool TreeView::IsTreePathValid(GtkTreePath *path)
 		if(!gtk_tree_model_get_iter(model, &iter, path))
 			return false;
 	}
-	
+
 	return bSuccess;
 }
 
@@ -194,7 +194,7 @@ GtkTreePath *TreeView::GetFirstVisibleNode()
 {
 	GtkTreeView *treeview = (GtkTreeView *)m_pWidget;
 	GtkTreeViewColumn *column1 = gtk_tree_view_get_column(treeview, 0);
-	
+
 	GtkTreePath *path1 = NULL;
 	if(gtk_tree_view_get_path_at_pos(treeview, 3, 3, &path1, &column1, NULL, NULL))
 	{
@@ -219,7 +219,7 @@ bool TreeView::GetNextVisibleNode(GtkTreePath **path1)
 	if(!gtk_tree_model_get_iter(model, &iter, *path1))
 		return false;
 
-	if( gtk_tree_model_iter_has_child(model, &iter) && 
+	if( gtk_tree_model_iter_has_child(model, &iter) &&
 		gtk_tree_view_row_expanded(treeview, *path1))
 	{
 		//select first child
@@ -243,7 +243,7 @@ bool TreeView::GetNextVisibleNode(GtkTreePath **path1)
 		}
 		else
 		{
-			//there is no sibling available, so move up 
+			//there is no sibling available, so move up
 			GtkTreeIter iterParent;
 			int nDepth = gtk_tree_path_get_depth (*path1);	//get current depth - for convinience
 			gboolean foundNextNode = FALSE;
@@ -260,7 +260,7 @@ bool TreeView::GetNextVisibleNode(GtkTreePath **path1)
 				iter = iterParent;
 				if( gtk_tree_model_iter_next( model, &iterParent ) ) foundNextNode = TRUE;
 			} while ( !foundNextNode );
-			
+
 			if( foundNextNode ) {
 				gtk_tree_path_free(*path1);
 				*path1 = gtk_tree_model_get_path(model, &iterParent);
@@ -286,7 +286,7 @@ bool TreeView::GetPreviousVisibleNode(GtkTreePath **path1)
 		while(1)
 		{
 			//if item has expanded children
-			if( gtk_tree_model_iter_has_child(model, &iter) && 
+			if( gtk_tree_model_iter_has_child(model, &iter) &&
 				gtk_tree_view_row_expanded(treeview, *path1))
 			{
 				//find last child
@@ -414,7 +414,7 @@ void TreeView::SelectionEnd()
 		//position on the last sibling on this level (if not already)
 		GtkTreeIter parent;
 		gboolean bParent = gtk_tree_model_iter_parent(model, &parent, &iter);
-		
+
 		//position to last parent's child
 		int nChildren = gtk_tree_model_iter_n_children (model, (bParent)? &parent : NULL);
 		if(nChildren < 1)
@@ -429,7 +429,7 @@ void TreeView::SelectionEnd()
 			path1 = gtk_tree_model_get_path(model, &iter);
 
 			//if expanded children exist
-			if(  gtk_tree_model_iter_has_child(model, &iter) && 
+			if(  gtk_tree_model_iter_has_child(model, &iter) &&
 				 gtk_tree_view_row_expanded(treeview, path1))
 			{
 				//position to last child
@@ -457,7 +457,7 @@ void TreeView::SelectionHome()
 	//select first item
 	GtkTreeView *treeview = (GtkTreeView *)m_pWidget;
 	GtkTreeModel *model = gtk_tree_view_get_model(treeview);
-	
+
 	GtkTreeIter iter;
 	if(gtk_tree_model_iter_children(model, &iter, NULL))
 	{
@@ -488,7 +488,7 @@ void TreeView::SelectionLevelDown()
 		else
 		{
 			//select first child
-			gtk_tree_path_down(path1); 
+			gtk_tree_path_down(path1);
 			GtkTreeViewColumn *column1 = gtk_tree_view_get_column(treeview, 0);
 			gtk_tree_view_set_cursor(treeview, path1, column1, FALSE);	//refresh node selection
 		}
@@ -648,15 +648,47 @@ void TreeView::WrapTreeToSize(int nSize)
 	GList *list1 = gtk_tree_view_column_get_cell_renderers(column1);
 	GtkCellRendererText *renderer = (GtkCellRendererText *)g_list_nth_data(list1, SCREEN_IDX_TEXT);
 
-	g_object_set (G_OBJECT (renderer), 
+	g_object_set (G_OBJECT (renderer),
 		"wrap-mode", PANGO_WRAP_CHAR,
-		"wrap-width", nSize, 
+		"wrap-width", nSize,
 		(char *)NULL);
 }
 
 void TreeView::SetTreeLines(bool bTree)
 {
+#if GTK_CHECK_VERSION(2,10,0)
 	g_object_set (G_OBJECT (m_pWidget),
 		"enable-tree-lines", bTree,
 		(char *)NULL);
+#endif
+}
+
+bool TreeView::IsPathInVisbleRange(GtkTreePath *path)
+{
+	bool bVisible = false;
+	GtkTreePath *start_path = NULL;
+	GtkTreePath *end_path = NULL;
+#if 0//GTK_CHECK_VERSION(2,8,0)
+	//TOFIX: this causes runtime GTK critical warnings in Linux console!
+	if(gtk_tree_view_get_visible_range(GTK_TREE_VIEW(m_pWidget), &start_path, &end_path)){
+#else
+	GdkRectangle rect;
+	gtk_tree_view_get_visible_rect(GTK_TREE_VIEW(m_pWidget), &rect);
+	gint bx = rect.x + rect.width - 2;
+	gint by = rect.y + rect.height - 2;
+	//gtk_tree_view_convert_tree_to_bin_window_coords(GTK_TREE_VIEW(m_pWidget), rect.x + rect.width - 2, rect.y + rect.height - 2, &bx, &by);
+	if(gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(m_pWidget), 0, 0, &start_path, NULL, NULL, NULL) &&
+	   gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(m_pWidget), bx, by, &end_path, NULL, NULL, NULL))
+	{
+#endif
+		//is the path within the visible range
+		if( gtk_tree_path_compare(path, start_path) >= 0 &&
+			gtk_tree_path_compare(path, end_path) <= 0)
+		{
+			bVisible = true;
+		}
+		gtk_tree_path_free(start_path);
+		gtk_tree_path_free(end_path);
+	}
+	return bVisible;
 }
