@@ -27,7 +27,7 @@
     #define snprintf _snprintf
    #endif
  #endif
-#endif 
+#endif
 
 #include "lib/NoteDocument.h"
 #include "lib/DocumentIterator.h"
@@ -146,13 +146,13 @@ void cell_edited_cancel_callback (GtkCellRenderer *renderer, gpointer user_data)
 void cell_edited_callback(GtkCellRendererText *cell, gchar *path_string, gchar *new_text, gpointer user_data)
 {
 	//do not allow empty node titles
-	if(0 == strlen(new_text))  
+	if(0 == strlen(new_text))
 		return;
 
 	//get document node index from GUI tree iterator
 	GtkTreePath* path1 = gtk_tree_path_new_from_string( path_string );
 	int nIdx = NodeIdxFromPath(path1);
-	
+
 	//
 	//store new text into the document node
 	//
@@ -168,7 +168,7 @@ void cell_edited_callback(GtkCellRendererText *cell, gchar *path_string, gchar *
 	//store new text into the tree store for given cell
 	GtkWidget *treeview = lookup_widget(window1, "treeview1");
 	GtkTreeModel *model = gtk_tree_view_get_model((GtkTreeView *)treeview);
-	
+
 	if(nIdx > -1){
 		GtkTreeIter iter;
 		gtk_tree_model_get_iter(model, &iter, path1);
@@ -176,7 +176,7 @@ void cell_edited_callback(GtkCellRendererText *cell, gchar *path_string, gchar *
 
 		//update node title label
 		set_title_bar(new_text);
-		
+
 		//if the name was actually changed
 		if(0 != strcmp(strOldTitle.c_str(), new_text))
 		{
@@ -195,7 +195,7 @@ void cell_edited_callback(GtkCellRendererText *cell, gchar *path_string, gchar *
 
 		RefreshMainTitle(); // updates modified doc state in window title bar
 	}
-	
+
 	gtk_tree_path_free(path1);
 
 	TreeView *pTree = (TreeView *)user_data;
@@ -220,7 +220,7 @@ int NodeIdxFromPath(GtkTreePath* path1)
 {
 	gint* arrIndices = gtk_tree_path_get_indices(path1);
 	int nMax = gtk_tree_path_get_depth(path1);
-	
+
 	int nIdx = -1;
 	int nParentID = -1;
 	DocumentIterator itDoc(g_doc);
@@ -232,7 +232,7 @@ int NodeIdxFromPath(GtkTreePath* path1)
 			break;	//TOFIX assert
 		nParentID = g_doc.GetNodeByIdx(nIdx).m_nID;
 	}
-	
+
 	return nIdx;
 }
 
@@ -240,7 +240,7 @@ int NodeIdxFromPath(GtkTreePath* path1)
 bool PathFromNodeIdx(int nIdx, GtkTreePath *&path1)
 {
 	std::string strPath;
-	
+
 	//prepare path string
 	while(nIdx >= 0)
 	{
@@ -248,14 +248,14 @@ bool PathFromNodeIdx(int nIdx, GtkTreePath *&path1)
 		char szLevel[30]="";
 		snprintf(szLevel, sizeof(szLevel), "%d:", g_doc.GetNodeByIdx(nIdx).m_nSiblingIdx);
 		strPath.insert(0, szLevel);
-		
+
 		//calculate parent index
 		nIdx = g_doc.GetIdxFromID(g_doc.GetNodeByIdx(nIdx).m_nParentID);
 	}
-	
+
 	//strip off last ':' character
 	strPath = strPath.substr(0, strPath.size()-1);
-	
+
 	//now convert that path string into the path object
 	path1 = gtk_tree_path_new_from_string(strPath.c_str());
 	return (path1 != NULL);
@@ -267,7 +267,7 @@ bool IteratorFromNodeIdx(int nIdx, GtkTreeIter &iter)
 	GtkTreePath *path1 = NULL;
 	if(!PathFromNodeIdx(nIdx, path1))
 		return false;
-	
+
 	GtkWidget *treeview = lookup_widget(window1, "treeview1");
 	GtkTreeModel *model = gtk_tree_view_get_model((GtkTreeView *)treeview);
 	bool bResult = (FALSE != gtk_tree_model_get_iter(model, &iter, path1));
@@ -283,7 +283,7 @@ void on_MRU_activate (GtkMenuItem *menuitem, gpointer user_data)
 	if(nIdx < (unsigned long)g_objMRU.GetFileCount())
 	{
 		std::string strFile = g_objMRU.GetFile(nIdx);
-		
+
 		//allow password being entered up to 3 times
 		int nResult = 0;
 		int nTryCnt = 0;
@@ -311,8 +311,8 @@ void register_extensions_check()
 #ifdef _WIN32
 	std::string strApp = GetAppPath();
 	std::string strCmd = strApp;
-	strCmd += " %1";
-	
+	strCmd += " \"%1\"";
+
 	RegisterFileExtension reg;
 	reg.SetFormatName("NoteCase.PlainFormat");
 	reg.SetExtension(".ncd");
@@ -441,7 +441,7 @@ int gtkMessageBox(const char *szText, int nButtons, int nIcon)
 #endif
 	gtk_window_set_resizable (GTK_WINDOW (msgbox), FALSE);
 	gtk_widget_realize(msgbox);
-	gdk_window_set_decorations(msgbox->window, (GdkWMDecoration)(GDK_DECOR_BORDER|GDK_DECOR_TITLE)); 
+	gdk_window_set_decorations(msgbox->window, (GdkWMDecoration)(GDK_DECOR_BORDER|GDK_DECOR_TITLE));
 
 #if 1
 	GtkWidget *dialog_vbox3 = GTK_DIALOG (msgbox)->vbox;
@@ -459,7 +459,7 @@ int gtkMessageBox(const char *szText, int nButtons, int nIcon)
 	else if(nButtons == GTK_BUTTONS_YES_NO){
 		gtk_dialog_add_button(GTK_DIALOG(msgbox), GTK_STOCK_YES,    GTK_RESPONSE_YES);
 		gtk_dialog_add_button(GTK_DIALOG(msgbox), GTK_STOCK_NO,     GTK_RESPONSE_NO);
-	}	
+	}
 
 	gtk_dialog_set_has_separator (GTK_DIALOG(msgbox), FALSE);
 #endif
@@ -498,7 +498,7 @@ int gtkMessageBoxYNC(const char *szText)
 #endif
 	gtk_window_set_resizable (GTK_WINDOW (msgbox), FALSE);
 	gtk_widget_realize(msgbox);
-	gdk_window_set_decorations(msgbox->window, (GdkWMDecoration)(GDK_DECOR_BORDER|GDK_DECOR_TITLE)); 
+	gdk_window_set_decorations(msgbox->window, (GdkWMDecoration)(GDK_DECOR_BORDER|GDK_DECOR_TITLE));
 
 	gtk_dialog_add_button(GTK_DIALOG(msgbox), GTK_STOCK_YES,    GTK_RESPONSE_YES);
 	gtk_dialog_add_button(GTK_DIALOG(msgbox), GTK_STOCK_NO,     GTK_RESPONSE_NO);
@@ -625,10 +625,10 @@ void ShowBusyCursor()
 		GdkCursor *cursor=gdk_cursor_new(GDK_WATCH);
 		gtk_widget_set_sensitive(GTK_WIDGET(window1),FALSE);
 
-		gdk_pointer_grab(window1->window, 
+		gdk_pointer_grab(window1->window,
 				TRUE,
 				(GdkEventMask)(GDK_POINTER_MOTION_MASK|GDK_BUTTON_PRESS_MASK|GDK_BUTTON_RELEASE_MASK),
-				NULL, 
+				NULL,
 				cursor,
 				GDK_CURRENT_TIME);
 		gdk_cursor_unref (cursor);
