@@ -106,10 +106,10 @@ int FormatIO_HTML::Load(const char *szFile, NoteDocument &doc)
 	}
 
 	IOProcess objFile(MODE_READ);
-	
+
 	// attach file read layer
 	IOLayerFile64 *pFileLayer = new IOLayerFile64;
-	objFile.PushLayer(pFileLayer);	
+	objFile.PushLayer(pFileLayer);
 
 	if(!pFileLayer->m_file.Open(szFile, F64_READ|F64_SHARE_READ|F64_OPEN_EXISTING))
 		return DOC_LOAD_NOT_FOUND;
@@ -159,7 +159,7 @@ int FormatIO_HTML::Save(const char *szFile, NoteDocument &doc)
 
 	// attach file write layer
 	IOLayerFile64 *pFileLayer = new IOLayerFile64;
-	objFile.PushLayer(pFileLayer);	
+	objFile.PushLayer(pFileLayer);
 
 	if(!pFileLayer->m_file.Open(szFile, F64_WRITE|F64_SHARE_READ|F64_OPEN_NEW))
 		return DOC_SAVE_ERR_FILE_OPEN;
@@ -186,7 +186,7 @@ void FormatIO_HTML::WriteDocContents(IOProcess &objFile)
 			objFile.WriteString("<!DOCTYPE NoteCenter-File>\n");
 		else
 			objFile.WriteString("<!DOCTYPE NoteCase-File>\n");
-	
+
 		//calc and write selected node "index"
 		if(m_pDoc->m_nCurrentNode >= 0){
 			char szLastNote[100];
@@ -209,7 +209,7 @@ void FormatIO_HTML::WriteDocContents(IOProcess &objFile)
 	objFile.WriteString(" ");
 	objFile.WriteString(APP_VER_STR);
 	objFile.WriteString("\">\n"); //<meta name="generator" content="WordPress 2.0.5" />
-	
+
 	if(m_bHtmlExport)
 	{
 		objFile.WriteString("<TITLE>");
@@ -246,7 +246,7 @@ void FormatIO_HTML::WriteDocContents(IOProcess &objFile)
 	g_objIni.GetValue("Export", "TabSize", nTabSize, 3);
 	g_strTabReplacement = "";
 	for(int i=0; i<nTabSize; i++)
-		g_strTabReplacement += "&nbsp;";
+		g_strTabReplacement += " ";//g_strTabReplacement += "&nbsp;";
 
 	if(m_bHtmlExport)
 	{
@@ -310,7 +310,7 @@ void FormatIO_HTML::OnTagBegin(const char *szTag, const char *szParams)
 	if(0 == strcasecmp(szTag, "DL"))	//DL indicates sublevel branching
 	{
 		m_nCurParentIdx = m_nCurNodeIdx;
-		m_nCurNodeIdx   = -1;	
+		m_nCurNodeIdx   = -1;
 	}
 	else if(0 == strcasecmp(szTag, "DT"))	//DT indicates new node title coming
 	{
@@ -353,7 +353,7 @@ void FormatIO_HTML::OnTagBegin(const char *szTag, const char *szParams)
 			if(nPos != std::string::npos)
 			{
 				//m_nDocParseState = DOC_PARSE_INSIDE_LINK;
-	
+
 				m_strLinkURL = m_strLinkURL.substr(nPos+strlen("href=\""));
 				if(m_strLinkURL.at(m_strLinkURL.size()-1) == '\"')
 					m_strLinkURL = m_strLinkURL.substr(0, m_strLinkURL.size()-1);
@@ -409,7 +409,7 @@ void FormatIO_HTML::OnTagBegin(const char *szTag, const char *szParams)
 				szTitlePos += strlen("title=\""); //point to the field data
 				const char *szEnd = strstr(szTitlePos, "\"");
 				if(szEnd){
-					strTitle.assign(szTitlePos, szEnd-szTitlePos); 
+					strTitle.assign(szTitlePos, szEnd-szTitlePos);
 				}
 			}
 
@@ -457,7 +457,7 @@ void FormatIO_HTML::OnTagBegin(const char *szTag, const char *szParams)
 				info.pixbuf  = pixbuf;
 				info.strName = strTitle;
 				m_pDoc->GetNodeByIdx(m_nCurNodeIdx).m_lstPictures.push_back(info);
-			
+
 				delete [] szDecode;
 
 				m_nPicCountInCurNode ++;
@@ -619,7 +619,7 @@ void FormatIO_HTML::OnTagBegin(const char *szTag, const char *szParams)
 	}
 }
 
-void FormatIO_HTML::OnTagEnd(const char *szTag)	
+void FormatIO_HTML::OnTagEnd(const char *szTag)
 {
 	//TRACE("FormatIO_HTML:[%s] tag end\n", szTag);
 
@@ -675,7 +675,7 @@ void FormatIO_HTML::OnTagEnd(const char *szTag)
 				//TOFIX parse date
 
 				delete [] szDecode;
-				
+
 				m_pDoc->GetNodeByIdx(m_nCurNodeIdx).m_lstAttachments.push_back(info);
 			}
 			else	//link
@@ -696,7 +696,7 @@ void FormatIO_HTML::OnTagEnd(const char *szTag)
 				else
 					m_pDoc->GetNodeByIdx(m_nCurNodeIdx).m_lstLinks.push_back(info);
 			}
-			
+
 			//clear internal data
 			m_strLinkURL = "";
 			m_strLinkText = "";
@@ -777,7 +777,7 @@ void FormatIO_HTML::OnTagEnd(const char *szTag)
 
 			int nPos1 = list.FindOppositeTag(FMT_TXT_BKG_COLOR_END, nCnt, false, true);
 			int nPos2 = list.FindOppositeTag(FMT_TXT_COLOR_END, nCnt, false, true);
-			
+
 			if(nPos1 > nPos2)
 			{
 				FmtInfo info;
@@ -837,7 +837,7 @@ void FormatIO_HTML::OnComment(const char *szText)
 		//TRACE("icon_internal->%s\n",szText);
 		//example tag: "<!--property:icon_internal=blank-->"
 		DocumentIterator it(*m_pDoc);
-		int nIdx = InternalIcon_Name2Index(szText + strlen("property:icon_internal="));		
+		int nIdx = InternalIcon_Name2Index(szText + strlen("property:icon_internal="));
 		if(nIdx >= 0)
 			m_pDoc->GetNodeByIdx(m_nCurNodeIdx).m_nIconType = nIdx;
 	}
@@ -895,6 +895,16 @@ void FormatIO_HTML::OnComment(const char *szText)
 		if(m_nCurNodeIdx >= 0)
 			m_pDoc->GetNodeByIdx(m_nCurNodeIdx).m_bExpanded = true;
 	}
+	else if (0 == strncmp(szText, "property:syntax_highlight=", strlen("property:syntax_highlight=")))
+	{
+		ASSERT(m_nCurNodeIdx >= 0);
+
+		if(m_nCurNodeIdx >= 0){
+			std::string strLang = szText + strlen("property:syntax_highlight=");
+			HTMLParser::UnescapeChars(strLang);
+			m_pDoc->GetNodeByIdx(m_nCurNodeIdx).GetSourceLanguage() = strLang;
+		}
+	}
 }
 
 void FormatIO_HTML::OnText(const char *szText)
@@ -971,7 +981,7 @@ void FormatIO_HTML::OnText(const char *szText)
 void FormatIO_HTML::ConvertInternalLinks()
 {
 	//
-	// convert recursive node index (as read from document file) 
+	// convert recursive node index (as read from document file)
 	// to the node ID value (as stored in memory, because ID is invariant)
 	// -> this is done once after the file was loaded from file
 	//
@@ -1054,7 +1064,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 			file.WriteString("<DT style=\"font-weight: bold;\">");
 		else
 			file.WriteString("<DT>");
-		
+
 		// if the node is a link target assign the name to it
 		if(bTarget){
 			int nRecursiveIdx = it.NodeIdx2RecursiveIdx(nIdx);
@@ -1146,6 +1156,15 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 				file.WriteString("-->\n");
 			}
 
+			//write note syntax highlighting language
+			if(!node.GetSourceLanguage().empty()){
+				std::string strLang = node.GetSourceLanguage();
+				HTMLParser::EscapeChars(strLang);
+				file.WriteString("<!--property:syntax_highlight=");
+				file.WriteString(strLang.c_str());
+				file.WriteString("-->\n");
+			}
+
 			//write node dates
 			char szBuffer[20];
 			snprintf(szBuffer, sizeof(szBuffer), "%d", (int)node.m_nDateCreated);//TOFIX? (long)
@@ -1157,7 +1176,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 			file.WriteString("<!--property:date_modified=");
 			file.WriteString(szBuffer);
 			file.WriteString("-->\n");
-		
+
 			if(node.m_bFinished){	// save only when set (TOFIX can remove =1 in the future)
 				snprintf(szBuffer, sizeof(szBuffer), "%d", node.m_bFinished);
 				file.WriteString("<!--property:finished=");
@@ -1181,7 +1200,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 
 			file.WriteString("<A title=\"");
 			file.WriteString(strTitle.c_str());
-			
+
 			if(bHtmlExport && g_bExportDataAsSeparateFile)
 			{
 				//save attachment as file
@@ -1195,7 +1214,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 					//use original name if it exists
 					sprintf(szBuffer, "%s%s", strDir.c_str(), node.m_lstAttachments[i].m_strName.c_str());
 					sprintf(szLocName, "%s", node.m_lstAttachments[i].m_strName.c_str());
-					
+
 				}
 				else{
 					sprintf(szBuffer, "%sAttachment%02d", strDir.c_str(), m_nExportAttCount);
@@ -1280,7 +1299,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 			lstSegments.push_back(info);
 		}
 
-		//before escaping, modify contents to include all node links 
+		//before escaping, modify contents to include all node links
 		//<A href="http://belle.monitor.hr/0510.htm">Belle de Jour</A>
 		int nLinks = node.m_lstLinks.size();
 		if(nLinks > 0)
@@ -1299,7 +1318,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 
 				//find segment for given offset (ignore link segments)
 				int nSegmentIdx = -1;
-				int nOffset = link.m_nStartOffset;		
+				int nOffset = link.m_nStartOffset;
 				int nOffsetTot = 0;
 				for(unsigned int j=0; j<lstSegments.size(); j++)
 				{
@@ -1337,13 +1356,13 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 						tSegment info;
 						info.strText = strTmp.substr(0, nPosBuf);
 						info.bIsText = bText;
-						
+
 						lstSegments.insert(lstSegments.begin()+nSegmentIdx, info);
 						nSegmentIdx++;
 					}
 
 					bool bSkipLink = false;
-					if( bHtmlExport && 
+					if( bHtmlExport &&
 						g_bConvertImageLinks &&
 						link.m_nTargetNodeID < 0)
 					{
@@ -1361,7 +1380,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 						{
 							std::string strLink;
 
-							//save link as an image 
+							//save link as an image
 							strLink += "<img alt=\"\" src=\"";
 							strLink += link.m_strTargetURL;
 							strLink += "\">";
@@ -1369,7 +1388,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 							tSegment info;
 							info.strText = strLink;
 							info.bIsText = false;
-							
+
 							lstSegments.push_back(info);
 							bSkipLink = true;
 						}
@@ -1437,7 +1456,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 				}
 			}
 		}
-		
+
 		//insert additional picture segments
 		int nPicsCount = node.m_lstPictures.size();
 		if(nPicsCount > 0)
@@ -1456,7 +1475,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 
 				//find segment for given offset (ignore link segments)
 				int nSegmentIdx = -1;
-				int nOffset = pix.nOffset;		
+				int nOffset = pix.nOffset;
 				int nOffsetTot = 0;
 				for(unsigned int j=0; j<lstSegments.size(); j++)
 				{
@@ -1620,9 +1639,9 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 
 						if(bWriteFile){
 							#if GTK_CHECK_VERSION(2,8,0) //new "compression" param TOFIX set proper version
-								gdk_pixbuf_save(pix.pixbuf, szPath, pix.bUsePNG? "png" : "jpeg", NULL, pix.bUsePNG? "compression" : NULL,  pix.bUsePNG? "9" : NULL, (char *)NULL);	//TOFIX check error	
+								gdk_pixbuf_save(pix.pixbuf, szPath, pix.bUsePNG? "png" : "jpeg", NULL, pix.bUsePNG? "compression" : NULL,  pix.bUsePNG? "9" : NULL, (char *)NULL);	//TOFIX check error
 							#else
-								gdk_pixbuf_save(pix.pixbuf, szPath, pix.bUsePNG? "png" : "jpeg", NULL, (char *)NULL);	//TOFIX check error	
+								gdk_pixbuf_save(pix.pixbuf, szPath, pix.bUsePNG? "png" : "jpeg", NULL, (char *)NULL);	//TOFIX check error
 							#endif
 						}
 
@@ -1688,7 +1707,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 
 				//find segment for given offset (ignore link segments)
 				int nSegmentIdx = -1;
-				int nOffset = fmt.nOffset;		
+				int nOffset = fmt.nOffset;
 				int nOffsetTot = 0;
 				for(unsigned int j=0; j<lstSegments.size(); j++)
 				{
@@ -1825,7 +1844,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 				}
 			}
 		}
-		
+
 		//escape segments (skipping link tags) and concatenate back to single string
 		strData = "";
 		unsigned int nMax = lstSegments.size();
@@ -1844,7 +1863,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 
 				if(bHtmlExport){
 					//convert spaces to non-breaking space
-					replaceall(strTmp, " ", "&nbsp;");
+					//replaceall(strTmp, " ", "&nbsp;");
 					replaceall(strTmp, "\t", g_strTabReplacement.c_str());
 				}
 			}
@@ -1925,7 +1944,7 @@ void FormatIO_HTML::WriteTOC(DocumentIterator &it, IOProcess &file, int nParentI
 
 		//if(nDepth > 0)
 			file.WriteString("</li>\n");
-	
+
 		//go to the next sibling node
 		nSiblingIdx ++;
 		nIdx = it.GetChildIdx(nParentID, nSiblingIdx);
